package com.example.catchTheLetters.service.impl;

import com.example.catchTheLetters.entity.Level;
import com.example.catchTheLetters.entity.ScoreInfo;
import com.example.catchTheLetters.model.vo.RankVo;
import com.example.catchTheLetters.service.LevelService;
import com.example.catchTheLetters.utils.JwtUtil;
import com.example.catchTheLetters.utils.R;
import jakarta.annotation.Resource;
import org.springframework.data.mongodb.core.MongoTemplate;
import org.springframework.data.mongodb.core.query.Criteria;
import org.springframework.data.mongodb.core.query.Query;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author 慕华
 * @date 2024/4/10
 * @Version 1.0
 * @description
 */
@Service
public class LevelServiceImpl implements LevelService {

    @Resource
    private MongoTemplate mongoTemplate;

    @Override
    public R<Level> levelDetail(String id) {
        Level level = mongoTemplate.findOne(new Query(Criteria.where("id").is(id)), Level.class);
        if (level == null){
            return R.fail("查询失败，请重试");
        }
        return R.ok(level);
    }

    @Override
    public R<List<Level>> list() {
        Query query = new Query();
        query.fields().include("id").include("name").include("type");
        List<Level> levels = mongoTemplate.find(query, Level.class);
        return R.ok(levels);
    }

    @Override
    public R<ScoreInfo> settle(ScoreInfo scoreInfo, String token) {
        var map = JwtUtil.getPayload(token);
        String id = null;
        if (map != null) {
            id = map.get("id").asString().replaceAll("\"", "");
        }
        if (id == null){
            return R.fail("token解析失败");
        }
        if (id.equals(scoreInfo.getUserId().toString())){
            ScoreInfo insert = mongoTemplate.insert(scoreInfo);
            return R.ok(insert);
        }
        return R.fail("添加失败，请重试");
    }

    @Override
    public RankVo getRankInfo(String levelId, String token) {
        // 在ScoreInfo表当中，查询levelId为levelId的所有数据，按照分数降序排列，取前10条数据
        var info = mongoTemplate.find(new Query(Criteria.where("levelId").is(levelId)).limit(10), ScoreInfo.class);

        var rankVo = new RankVo();
        rankVo.setScoreInfos(info);


        // 如果有token，就查自己的分数数据
        if (token != null) {
            var map = JwtUtil.getPayload(token);
            String id = null;
            if (map != null) {
                id = map.get("id").asString().replaceAll("\"", "");
            }
            if (id != null) {
                var myScore = mongoTemplate.findOne(new Query(Criteria.where("userId").is(id).and("levelId").is(levelId)), ScoreInfo.class);
                rankVo.setMyScore(myScore);
            }
        }

        return rankVo;
    }

    @Override
    public boolean levelCreate(Level level) {
        var insert = mongoTemplate.insert(level);
        return insert.getId() != null;
    }
}
